==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentBoolValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentBoolValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "Boolean");
        }
        static d(a) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
            a.ad("WebComponentBoolValueChangedEventArgs", () => new WebComponentBoolValueChangedEventArgsDescription());
            a.ac("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebComponentBoolValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebComponentBoolValueChangedEventArgsDescription } from "./WebComponentBoolValueChangedEventArgsDescription";
/**
 * @hidden
 */
export let WebComponentBoolValueChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebComponentBoolValueChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebComponentBoolValueChangedEventArgsDescriptionMetadata.a == null) {
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebComponentBoolValueChangedEventArgsDescriptionMetadata.c(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ComponentBoolValueChangedEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__marshalByValue", "Boolean");
            a.item("Detail", "Boolean");
        }
        static d(a) {
            WebComponentBoolValueChangedEventArgsDescriptionMetadata.b(a);
            a.ae("WebComponentBoolValueChangedEventArgs", () => new WebComponentBoolValueChangedEventArgsDescription());
            a.ad("WebComponentBoolValueChangedEventArgs", WebComponentBoolValueChangedEventArgsDescriptionMetadata.a);
        }
    }
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.$t = markType(WebComponentBoolValueChangedEventArgsDescriptionMetadata, 'WebComponentBoolValueChangedEventArgsDescriptionMetadata');
    WebComponentBoolValueChangedEventArgsDescriptionMetadata.a = null;
    return WebComponentBoolValueChangedEventArgsDescriptionMetadata;
})();
